/**
 * 
 */
package com.platomix.intchannel.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.enums.DealTypeEnum;
import com.platomix.intchannel.model.*;
import com.platomix.intchannel.service.*;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("/finance/channel")
@Api(value = "渠道管理", tags = "渠道管理接口")
@Slf4j
public class ChannelController {

	@Autowired
	private ChannelsService channelsService;
	
	@Autowired
	private ChannelSpidService channelSpidService;

	@Autowired
	private YksytChannelsService yksytChannelsService;

	@Autowired
	private ChannelSpidViewService channelSpidViewService;

	@Autowired
	private DimDealTypeService dimDealTypeService;

	@Autowired
	private DealUserViewService dealUserViewService;

	@Autowired
	private InnerComapnySpidService innerComapnySpidService;

	@Autowired
	private DealUserAccountsService dealUserAccountsService;



	/**
	 * 互联网1->渠道信息下拉列表
	 * @return
	 */
	@GetMapping("/hlwlist")
	@ApiOperation("互联网1->渠道信息下拉列表")
	public R hlwlist(){
		QueryWrapper<DealUserView> queryWrapper = new QueryWrapper<DealUserView>();
		queryWrapper.select("DEAL_USERID, DEAL_USER_NAME").isNotNull("DEAL_USERID");
		queryWrapper.eq("MODULE", DealTypeEnum.hlw1_deal.getValue());
		List<DealUserView> list = dealUserViewService.list(queryWrapper);
		List<Map<String, Object>> data = list.stream()
				.map(obj -> {
					Map<String, Object> map = new HashMap<>();
					map.put("dealUserid", obj.getDealUserid());
					map.put("dealUserName", obj.getDealUserName());
					return map;
				}).collect(Collectors.toList());
		return R.ok(data);
	}


	/**
	 * 渠道列表
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation("创建账号 -> 结算方账号公司信息下拉列表（替代原有得渠道下拉列表）")
	public R list(){
		/*List<Channels> channels = channelsService.list();
		List<YksytChannels> list = yksytChannelsService.list();
		if(list != null && list.size() > 0){
			for (YksytChannels yksytChannels : list) {
				Channels bean = new Channels();
				bean.setChannelId(yksytChannels.getChannelid());
				bean.setChannelName(yksytChannels.getChannelname());
				bean.setCompany(yksytChannels.getCompany());
				channels.add(bean);
			}
		}*/
		QueryWrapper<DealUserView> queryWrapper = new QueryWrapper<DealUserView>();
		queryWrapper.select("DEAL_USERID,DEAL_USER_NAME").isNotNull("DEAL_USERID");
		List<DealUserView> list = dealUserViewService.list(queryWrapper);
		List<Map<String, Object>> data = list.stream()
				.map(obj -> {
					Map<String, Object> map = new HashMap<>();
					map.put("dealUserid", obj.getDealUserid());
					map.put("dealUserName", obj.getDealUserName());
					return map;
				}).collect(Collectors.toList());
		return R.ok(data);
	}


	@GetMapping("/dealTypeList")
	@ApiOperation("创建账号 -> 结算类型下拉列表")
	public R dealTypeList(){
		List<DimDealType> list = dimDealTypeService.list();
		List<Map<String, Object>> data = list.stream()
				.map(obj -> {
					Map<String, Object> map = new HashMap<>();
					map.put("dealTypeId", obj.getDealTypeId());
					map.put("dealType", obj.getDealType());
					return map;
				}).collect(Collectors.toList());
		return R.ok(data);
	}


	/**
	 * 优酷收银台渠道详细信息
	 * @return
	 */
	@GetMapping("/channelDet")
	@ApiOperation("当前渠道信息")
	public R<List<ChannelSpidView>> channelDet(){
		List<String> collect = getDealUserAccounts(TokenUtil.getDealUserId());
		return R.ok(channelSpidViewService.list(Wrappers.<ChannelSpidView>lambdaQuery()
				.in(ChannelSpidView::getDealAccountId, collect))
		);
	}


	/**
	 * 渠道信息
	 * @return
	 */
	@GetMapping("/currInfo")
	@ApiOperation("当前渠道信息")
	public R<List<ChannelSpid>> info(){
		List<String> collect = getDealUserAccounts(TokenUtil.getDealUserId());
		//社会渠道
		return R.ok(channelSpidService.list(Wrappers.<ChannelSpid>lambdaQuery().in(ChannelSpid::getDealAccountId, collect)));
	}

	/**
	 * 内部渠道结算当前渠道信息
	 * @return
	 */
	@GetMapping("/innerChannel")
	@ApiOperation("内部渠道结算当前渠道信息")
	public R<List<InnerComapnySpid>> innerChannel(){
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());
		return R.ok(innerComapnySpidService.list(Wrappers.<InnerComapnySpid>lambdaQuery().in(InnerComapnySpid::getDealAccountId, collect)));
	}


	/**
	 * 渠道信息
	 * @return
	 */
	@GetMapping("/channelInfo")
	@ApiOperation("渠道商端获取当前登录账户的渠道信息（整合）")
	public R channelInfo(){
		String dealUserId = TokenUtil.getDealUserId();
		DealUserView dealUser = dealUserViewService.getOne(new LambdaQueryWrapper<DealUserView>()
				.eq(DealUserView::getDealUserid, dealUserId)
		);
		if(dealUser == null){
			return R.fail("用户信息不存在");
		}
		List<String> collect = getDealUserAccounts(dealUserId);
		//社会渠道
		if(dealUser.getModule() == 1 || dealUser.getModule() == 2){
			return R.ok(channelSpidService.list(Wrappers.<ChannelSpid>lambdaQuery().in(ChannelSpid::getDealAccountId, collect)));
		}
		//其他渠道
		if(dealUser.getModule() == 3){
			return R.ok(channelSpidViewService.list(Wrappers.<ChannelSpidView>lambdaQuery()
					.in(ChannelSpidView::getDealAccountId, collect)
					.ne(ChannelSpidView::getDealType,2))
			);
		}
		//会员权益
		if(dealUser.getModule() == 4){
			return R.ok(channelSpidViewService.list(Wrappers.<ChannelSpidView>lambdaQuery()
					.in(ChannelSpidView::getDealAccountId, collect)
					.eq(ChannelSpidView::getDealType,2))
			);
		}
		//内部结算
		if(dealUser.getModule() == 5){
			return R.ok(innerComapnySpidService.list(Wrappers.<InnerComapnySpid>lambdaQuery().in(InnerComapnySpid::getDealAccountId, collect)));
		}
		return R.ok();
	}


	private List<String> getDealUserAccounts(String dealUserId){
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());
		return collect;
	}

}
