/**
 * 
 */
package com.platomix.intchannel.controller;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.model.DateRangeAccount;
import com.platomix.intchannel.model.DealUserAccounts;
import com.platomix.intchannel.service.DateRangeAccountService;
import com.platomix.intchannel.service.DealUserAccountsService;
import com.platomix.intchannel.service.FinanceBillAuditService;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author wookvn
 *
 */
@RestController
@RequestMapping("/finance/dateRangeAccount")
@Api(value = "渠道结算", tags = "渠道结算接口")
public class DateRangeAccountController {

	@Autowired
	private DateRangeAccountService dateRangeAccountService;

	@Autowired
	private DealUserAccountsService dealUserAccountsService;


	/**
	 * @return
	 */
	@GetMapping("/page")
	@ApiOperation("渠道结算明细")
	public R<IPage<DateRangeAccount>> page(Integer current,Integer size){
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());

		Page<DateRangeAccount> page = new Page<>(current,size);
		IPage<DateRangeAccount> resultPage = dateRangeAccountService.page(page, new LambdaQueryWrapper<DateRangeAccount>()
			.in(DateRangeAccount::getDealAccountId, collect)
			.orderByDesc(DateRangeAccount::getTheMonth)
		);

		if(resultPage != null && resultPage.getRecords() != null) {
			resultPage.getRecords().forEach(f -> {
				LocalDate localDate = null;
				if(StringUtils.isEmpty(f.getTheMonth())) {
					localDate = LocalDate.now();
				}else {
					localDate = LocalDate.parse(f.getTheMonth()+"01", DateTimeFormatter.BASIC_ISO_DATE);
				}
				LocalDate t1LocalDate = localDate.plusMonths(-1);

				Integer t1TheMonth = Integer.valueOf(DateTimeFormatter.ofPattern("yyyyMM").format(t1LocalDate));

				f.setReadyTypeStr(f.getTheMonth().intValue() == t1TheMonth ? "T+1预结" : "T+5清算");
			});
		}
		return R.ok(resultPage);
	}


	/**
	 * @return
	 */
	@GetMapping("/list")
	@ApiOperation(value = "结算表数据")
	public R<IPage<DateRangeAccount>> list(Integer current,Integer size){
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());

		Page<DateRangeAccount> page = new Page<>(current,size);
		LambdaQueryWrapper<DateRangeAccount> queryWrapper = Wrappers.<DateRangeAccount>lambdaQuery();
		queryWrapper.in(DateRangeAccount::getDealAccountId, collect);
		Integer thisMonth = Integer.valueOf(DateTimeFormatter.ofPattern("yyyyMM").format(LocalDate.now()));
		queryWrapper.lt(DateRangeAccount::getTheMonth, thisMonth);
		IPage<DateRangeAccount> pageResult = dateRangeAccountService.page(page, queryWrapper.orderByDesc(DateRangeAccount::getTheMonth));
		return R.ok(pageResult);
	}

}
