/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package com.platomix.intchannel.controller;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.poi.excel.ExcelUtil;
import com.alibaba.excel.EasyExcel;
import com.alibaba.excel.ExcelWriter;
import com.alibaba.excel.support.ExcelTypeEnum;
import com.alibaba.excel.write.metadata.WriteSheet;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.itextpdf.text.*;
import com.itextpdf.text.pdf.BaseFont;
import com.itextpdf.text.pdf.PdfPCell;
import com.itextpdf.text.pdf.PdfPTable;
import com.itextpdf.text.pdf.PdfWriter;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.dto.ProvDetailExcel;
import com.platomix.intchannel.enums.AuditStatusEnum;
import com.platomix.intchannel.model.*;
import com.platomix.intchannel.service.*;
import com.platomix.intchannel.utils.Convert;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.io.ClassPathResource;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.ByteArrayOutputStream;
import java.net.URLEncoder;
import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 内部结算-结算单审核表 控制器
 *
 * @author zbc
 * @since 2022-07-20
 */
@RestController
@RequestMapping("finance/innerBillAudit")
@Api(value = "内部结算-结算单审核表", tags = "内部结算-结算单审核表接口")
@Slf4j
public class InnerBillAuditController {

	@Autowired
	private InnerBillAuditUserService innerBillAuditUserService;

	@Autowired
	private InnerDealDetailService innerDealDetailService;

	@Autowired
	private InnerBillAuditService innerBillAuditService;

	@Autowired
	private InnerAccountService innerAccountService;

	@Autowired
	private DealUserAccountsService dealUserAccountsService;

	@Autowired
	private InnerBackFileService innerBackFileService;

	@Autowired
	private InnerDealProvDetailViewService innerDealProvDetailViewService;



	@GetMapping("/page")
	@ApiOperation(value = "分页查询内部结算-推送结算单")
	public R<IPage<InnerBillAudit>> page(Integer pageNum, Integer limit){
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("DEAL_ACCOUNT_ID").isNotNull("DEAL_ACCOUNT_ID");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getDealAccountId).collect(Collectors.toList());

		QueryWrapper<InnerBillAudit> queryWrapper = Wrappers.<InnerBillAudit>query();
		queryWrapper.in("ia.DEAL_ACCOUNT_ID", collect)
			.in("iba.AUDITSTATUS", AuditStatusEnum.fin_reject.getValue(), AuditStatusEnum.fin_upload.getValue(), AuditStatusEnum.wait_upload.getValue());
		queryWrapper.orderByDesc("iba.AID");
		Page<InnerBillAudit> page = new Page<>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		//符合条件的aid List
		List<Long> aidList = innerBillAuditService.customAidList(page, queryWrapper);
		IPage<InnerBillAudit> customPage = new Page<InnerBillAudit>(Convert.toInt(pageNum, 1), Convert.toInt(limit, 10));
		if (aidList != null && !aidList.isEmpty()) {
			customPage.setTotal(innerBillAuditService.customCount(queryWrapper));
			List<InnerBillAudit> custom = innerBillAuditService.customList(Wrappers.<InnerBillAudit>query().in("iba.AID", aidList));

			if(custom != null && custom.size() > 0){
				for (InnerBillAudit innerBillAudit : custom) {
					//回传文件列表
					List<InnerBackFile> backFiles = innerBackFileService.list(new LambdaQueryWrapper<InnerBackFile>()
							.eq(InnerBackFile::getAid, innerBillAudit.getAid())
							.eq(InnerBackFile::getIsdelete, 0)
							.orderByDesc(InnerBackFile::getUploadtime)
					);
					if(backFiles != null && backFiles.size() > 0){
						innerBillAudit.setFid(backFiles.get(0).getFid().toString());
						innerBillAudit.setUploadfilename(backFiles.get(0).getUploadfilename());
						innerBillAudit.setUploadfileuri(backFiles.get(0).getUploadfileuri());
						innerBillAudit.setUploadTime(backFiles.get(0).getUploadtime());
					}


					List<InnerDealDetail> list = null;
					list = innerDealDetailService.list(new LambdaQueryWrapper<InnerDealDetail>()
						.eq(InnerDealDetail::getSid,innerBillAudit.getSid())
					);
					if(list != null && list.size() > 0){
						innerBillAudit.setDaelList(list);
					}
				}
			}
			customPage.setRecords(custom);
		}
		return R.ok(customPage);
	}


	/**
	 * 驳回
	 * @param aid
	 * @param rejectReason
	 * @return
	 */
	@PostMapping("/reject")
	@ApiOperation(value = "驳回接口")
	public R<String> reject(String aid, String rejectReason){
		InnerBillAudit entity = new InnerBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setRejectreason(rejectReason);
		entity.setAuditstatus(AuditStatusEnum.fin_reject.getValue());
		entity.setRejecttime(new Date());
		return R.status(innerBillAuditService.updateById(entity));
	}

	/**
	 *
	 * @param aid
	 * @return
	 */
	@PostMapping("/confirm")
	@ApiOperation(value = "确认接收接口")
	public R<String> cancel(String aid){
		InnerBillAudit entity = new InnerBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setAuditstatus(AuditStatusEnum.wait_upload.getValue());
		return R.status(innerBillAuditService.updateById(entity));
	}


	@PostMapping("/upload")
	@ApiOperation(value = "回传接口")
	public R<String> upload(String aid, String uploadFileName, String uploadFileUri){
		InnerBillAudit entity = new InnerBillAudit();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadfilename(uploadFileName);
		entity.setUploadfileuri(uploadFileUri);
		entity.setAuditstatus(AuditStatusEnum.fin_upload.getValue());
		return R.status(innerBillAuditService.updateById(entity));
	}


	/**
	 * 回传接口
	 * @param aid
	 * @return
	 */
	@PostMapping("/backFile")
	@ApiOperation(value = "二次回传接口")
	public R backFile(String aid, String uploadFileName, String uploadFileUri){
		InnerBackFile entity = new InnerBackFile();
		entity.setAid(Long.valueOf(aid));
		entity.setUploadfilename(uploadFileName);
		entity.setUploadfileuri(uploadFileUri);
		entity.setUploadtime(new Date());
		entity.setIsdelete(0);
		boolean sa = innerBackFileService.save(entity);
		if(sa){
			InnerBillAudit audit = innerBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditstatus(AuditStatusEnum.fin_upload.getValue());
				return R.status(innerBillAuditService.updateById(audit));
			}
			return R.fail("结算单不存在");
		}
		return R.fail("回传文件失败");
	}


	/**
	 * 删除回传文件
	 * @param aid
	 * @param fid
	 * @return
	 */
	@PostMapping("/removeFile")
	@ApiOperation(value = "删除回传文件")
	public R removeFile(String aid, Long fid){
		InnerBackFile backFile = innerBackFileService.getById(fid);
		if(backFile == null){
			return R.fail("文件不存在");
		}
		backFile.setIsdelete(1);
		boolean edit = innerBackFileService.updateById(backFile);
		if(edit){
			InnerBillAudit audit = innerBillAuditService.getById(aid);
			if(audit != null){
				audit.setAuditstatus(AuditStatusEnum.wait_upload.getValue());
				return R.status(innerBillAuditService.updateById(audit));
			}
		}
		return R.fail("删除回传文件失败");
	}


	@GetMapping("/provDetailPage")
	@ApiOperation(value = "分页查询-内部结算-省分明细表")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "startTime", value = "开始月份(格式：yyyyMM)", dataType = "string", required = false),
			@ApiImplicitParam(name = "endTime", value = "结束月份(格式：yyyyMM)", dataType = "string", required = false)
	})
	public R<IPage<InnerDealProvDetailView>> provDetailPage(String startTime, String endTime, Integer current,Integer size){
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("COMPANY").isNotNull("COMPANY");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getCompany).collect(Collectors.toList());
		LambdaQueryWrapper<InnerDealProvDetailView> queryWrapper = Wrappers.<InnerDealProvDetailView>lambdaQuery();
		queryWrapper.in(InnerDealProvDetailView::getCompany,collect);
		if(StringUtils.isNotBlank(startTime)) {
			int startDate = Integer.valueOf(startTime);
			queryWrapper.ge(InnerDealProvDetailView::getThemonth, startDate);
		}
		if(StringUtils.isNotBlank(endTime)) {
			int endDate = Integer.valueOf(endTime);
			queryWrapper.le(InnerDealProvDetailView::getThemonth, endDate);
		}
		Page<InnerDealProvDetailView> page = new Page<>(current,size);
		IPage<InnerDealProvDetailView> pageResult = innerDealProvDetailViewService.page(page, queryWrapper.orderByDesc(InnerDealProvDetailView::getThemonth));
		return R.ok(pageResult);
	}


	@GetMapping("/provDetailExport")
	@ApiOperation(value = "内部结算-省分明细表导出")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "startTime", value = "开始月份(格式：yyyyMM)", dataType = "string", required = false),
			@ApiImplicitParam(name = "endTime", value = "结束月份(格式：yyyyMM)", dataType = "string", required = false)
	})
	public void provDetailExport(String company, String startTime, String endTime, HttpServletResponse response)  throws Exception  {
		String dealUserId = TokenUtil.getDealUserId();
		QueryWrapper<DealUserAccounts> dealQueryWrapper = new QueryWrapper<DealUserAccounts>();
		dealQueryWrapper.select("COMPANY").isNotNull("COMPANY");
		dealQueryWrapper.eq("DEAL_USERID",dealUserId);
		List<DealUserAccounts> dealList = dealUserAccountsService.list(dealQueryWrapper);
		List<String> collect = dealList.stream().map(DealUserAccounts::getCompany).collect(Collectors.toList());
		LambdaQueryWrapper<InnerDealProvDetailView> queryWrapper = Wrappers.<InnerDealProvDetailView>lambdaQuery();
		queryWrapper.in(InnerDealProvDetailView::getCompany,collect);
		if(StringUtils.isNotBlank(startTime)) {
			int startDate = Integer.valueOf(startTime);
			queryWrapper.ge(InnerDealProvDetailView::getThemonth, startDate);
		}
		if(StringUtils.isNotBlank(endTime)) {
			int endDate = Integer.valueOf(endTime);
			queryWrapper.le(InnerDealProvDetailView::getThemonth, endDate);
		}
		List<InnerDealProvDetailView> resultList = innerDealProvDetailViewService.list(queryWrapper.orderByDesc(InnerDealProvDetailView::getThemonth));
		List<ProvDetailExcel> excelList = new ArrayList<ProvDetailExcel>();
		if(resultList != null && resultList.size() > 0) {
			for (InnerDealProvDetailView item : resultList) {
				excelList.add(BeanUtil.copyProperties(item, ProvDetailExcel.class));
			}
		}
		response.setContentType("application/vnd.ms-excel");
		response.setCharacterEncoding("utf-8");
		// 这里URLEncoder.encode可以防止中文乱码 当然和easyexcel没有关系
		String fileName = URLEncoder.encode("省份明细表", "UTF-8");
		response.setHeader("Content-disposition", "attachment;filename=" + fileName + ".xlsx");
		ExcelWriter excelWriter = EasyExcel.write(response.getOutputStream())
				.excelType(ExcelTypeEnum.XLSX).build();
		WriteSheet writeSheet = EasyExcel.writerSheet("省份明细").head(ProvDetailExcel.class).build();
		excelWriter.write(excelList, writeSheet);
		excelWriter.finish();
		//ExcelUtil.export(response, "省份明细表", "省份明细", excelList, ProvDetailExcel.class);
	}


	/**
	 * @throws Exception
	 */
	@GetMapping("/downloadPdf")
	@ApiOperation(value = "下载内部结算单PDF")
	@ApiImplicitParams({
			@ApiImplicitParam(name = "sid", value = "序号", dataType = "Integer", required = true)
	})
	public void downloadPdf(@RequestParam String sid, HttpServletResponse response) throws Exception {
		LambdaQueryWrapper<InnerAccount> queryWrapper = Wrappers.lambdaQuery(InnerAccount.class).eq(InnerAccount::getSid, sid);
		InnerAccount innerAccount = innerAccountService.getOne(queryWrapper);
		if(innerAccount != null) {
			DealUserAccounts accounts = dealUserAccountsService.getOne(new LambdaQueryWrapper<DealUserAccounts>()
					.eq(DealUserAccounts::getDealAccountId, innerAccount.getDealAccountId())
			);
			// Http 1.0 header
			response.setDateHeader("Expires", 0);
			response.addHeader("Pragma", "no-cache");
			// Http 1.1 header
			response.setHeader("Cache-Control", "no-cache");
			String encodedfileName = new String((innerAccount.getCompany()+"结算确认单").getBytes("GBK"), "ISO8859-1");
			response.setHeader("Content-Disposition", "attachment; filename=\"" + encodedfileName + ".pdf\"");
			response.setContentType("application/vnd.ms-pdf");

			ByteArrayOutputStream baos = new ByteArrayOutputStream();
			if(accounts != null && accounts.getDealUserid().equals("inn_rh_wo_assis")){
				createPdfWzl(innerAccount, baos);
			}else {
				createPdfNbjs(innerAccount, baos);
			}
			response.getOutputStream().write(baos.toByteArray());
			response.getOutputStream().flush();
		}
	}


	/**
	 * 内部结算类型PDF
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfNbjs(InnerAccount data, ByteArrayOutputStream baos) throws Exception {
		List<InnerDealDetail> list = null;
		if(data.getSid() != null){
			list = innerDealDetailService.list(new LambdaQueryWrapper<InnerDealDetail>()
					.eq(InnerDealDetail::getSid,data.getSid())
			);
		}

		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(4);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(4);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《%s结算确认单》", data.getDealType()), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算账期", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("甲方：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("联通在线信息科技有限公司", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方：" , titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getCompany(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("合同编号", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(" ", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("业务名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("结算用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("采购单价(含税)", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("小计(含税)", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		if(list != null && list.size() > 0){
			for (InnerDealDetail detail : list) {
				cell = new PdfPCell(new Phrase(detail.getSpname(), titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getUsernum().toString(), titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getDealPrice() + "", titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getMoney() + "" ,titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
			}
		}


		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase(24,
				"甲方：联通在线信息科技有限公司 \n" +
						"\n\n\n" +
						"盖章：\n\n\n\n" +
						"\n\n\n" +
						"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(24,
				"乙方：" + data.getCompany() +" \n" +
						"\n\n\n" +
						"盖章：\n\n\n\n" +
						"\n\n\n" +
						"日期：",
				titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}

	/**
	 * 沃助理单独处理
	 * @param data
	 * @param baos
	 * @throws Exception
	 */
	private void createPdfWzl(InnerAccount data, ByteArrayOutputStream baos) throws Exception {
		List<InnerDealDetail> list = null;
		if(data.getSid() != null){
			list = innerDealDetailService.list(new LambdaQueryWrapper<InnerDealDetail>()
					.eq(InnerDealDetail::getSid,data.getSid())
			);
		}

		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = data.getThemonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(4);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(4);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《%s结算确认单》", data.getDealType()), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("结算账期", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("甲方：", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("畅视事业部", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方：" , titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(data.getCompany(), titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("合同编号", titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(" ", titleFont));
		cell.setColspan(4);
		cell.setPadding(10f);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("业务名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("结算用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("采购单价(含税)", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("小计(含税)", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		if(list != null && list.size() > 0){
			for (InnerDealDetail detail : list) {
				cell = new PdfPCell(new Phrase(detail.getSpname(), titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getUsernum().toString(), titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getDealPrice() + "", titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
				cell = new PdfPCell(new Phrase(detail.getMoney() + "" ,titleFont));
				cell.setPadding(10f);
				table.addCell(cell);
			}
		}


		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}



}
