/**
 * 
 */
package com.platomix.intchannel.controller;

import cn.hutool.captcha.CaptchaUtil;
import cn.hutool.captcha.GifCaptcha;
import cn.hutool.core.lang.UUID;
import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.platomix.intchannel.config.R;
import com.platomix.intchannel.manager.ICacheManager;
import com.platomix.intchannel.model.ChannelUser;
import com.platomix.intchannel.model.DealUserView;
import com.platomix.intchannel.service.ChannelUserService;
import com.platomix.intchannel.service.DealUserViewService;
import com.platomix.intchannel.utils.AESUtil;
import com.platomix.intchannel.utils.RedisUtil;
import com.platomix.intchannel.utils.TokenUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.HashMap;
import java.util.Map;

/**
 * @author wookvn
 *
 *	登录授权
 */
@RestController
@Api(value = "登录", tags = "登录接口")
@Slf4j
public class LoginController {

	@Autowired
	private ChannelUserService channelUserService;

	@Autowired
	private DealUserViewService dealUserViewService;
	
	@Autowired
	private ICacheManager cacheManager;

	@Autowired
	private RedisUtil redisUtil;
	
	/**
	 * 登录
	 * @param userName
	 * @param passWord
	 * @param captcha
	 * @return
	 */
	@PostMapping("/login")
	@ApiOperation(value = "登录接口")
	public R<String> login(@RequestParam String userName, 
			@RequestParam String passWord, 
			@RequestParam String captchaKey,
			@RequestParam String captcha) throws Exception {
		String key = "v+S6SPsiYr1pSmQa";
		String decode = AESUtil.Decrypt(userName, key);
		String decodePwd = AESUtil.Decrypt(passWord, key);
		log.info("decode  u = {} p = {}",decode,decodePwd);
		String code = (String) redisUtil.get(captchaKey);
		log.info("图形验证码: {},{}", captcha, code);
		if (StrUtil.isBlank(code)) {
			return R.fail("验证码已失效");
		}
		redisUtil.del(captchaKey);
		if (!code.equals(captcha)) {
			return R.fail("图形验证码错误");
		}
/*		ChannelUser channelUser = channelUserService.getOne(Wrappers.lambdaQuery(ChannelUser.class)
				.eq(ChannelUser::getUserName, userName).eq(ChannelUser::getPassWord, MD5.create().digestHex(passWord)));*/
		ChannelUser channelUser = channelUserService.getOne(Wrappers.lambdaQuery(ChannelUser.class)
				.eq(ChannelUser::getUserName, decode).eq(ChannelUser::getPassWord, decodePwd));

		if(channelUser != null) {
			if(channelUser.getDealUserid().equals("0")){
				String token = TokenUtil.createToken(channelUser);
				return R.ok(token, "0", "登录成功");
			}
			DealUserView dealUser = dealUserViewService.getOne(new LambdaQueryWrapper<DealUserView>()
					.eq(DealUserView::getDealUserid, channelUser.getDealUserid())
			);
			String token = TokenUtil.createToken(channelUser);
			return R.ok(token, dealUser.getModule().toString(), "登录成功");
		}
		return R.fail("用户名密码错误");
	}


	/**
	 * 生成验证码
	 */
	@GetMapping(value = "/getverify")
	@ApiOperation(value = "生成验证码", notes = "生成验证码")
	public Map getverify() {
		String captchaCacheKey = UUID.randomUUID().toString();
		GifCaptcha gifCaptcha = CaptchaUtil.createGifCaptcha(240, 100);
		// 重新生成code
		gifCaptcha.setQuality(1);
		gifCaptcha.createCode();
		redisUtil.set(captchaCacheKey, gifCaptcha.getCode(),6000);
		Map<String, Object> map = new HashMap<>();
		map.put("key", captchaCacheKey);
		map.put("image", gifCaptcha.getImageBase64Data());
		return map;
	}


}
