/**
 * 
 */
package com.platomix.intchannel.interceptor;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.dao.DuplicateKeyException;
import org.springframework.validation.BindException;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.annotation.ExceptionHandler;
import org.springframework.web.bind.annotation.RestControllerAdvice;
import org.springframework.web.servlet.NoHandlerFoundException;

import com.platomix.intchannel.config.R;

/**
 * @author wookvn
 *	Controller全局异常捕获
 */
@RestControllerAdvice
public class GlobalExceptionAdvice {

	private static final Logger LOGGER = LoggerFactory.getLogger(GlobalExceptionAdvice.class);
	
	/**
	 * 数据重复异常监控
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(DuplicateKeyException.class)
	public Object handleException(DuplicateKeyException ex) {
		return invoke("数据已存在，请更正后重新提交。", ex, true);
	}
	
	/**
	 * 	校验框架异常
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(BindException.class)
	public Object handleBindException(BindException ex) {
		return invoke(ex.getAllErrors().get(0).getDefaultMessage(), ex, true);
	}
	
	/**
	 * 	参数校验异常处理
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(MethodArgumentNotValidException.class)
	public Object handleMethodArgumentNotValidException(MethodArgumentNotValidException ex) {
		return invoke(ex.getBindingResult().getAllErrors().stream().findFirst().get().getDefaultMessage(), ex, false);
	}
	
	/**
	 * 	请求方式异常处理
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(HttpRequestMethodNotSupportedException.class)
	public Object handleHttpRequestMethodNotSupportedException(HttpRequestMethodNotSupportedException ex) {
		return invoke("HTTP请求方式错误~", ex, false);
	}
	
	/**
	 * 
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(NoHandlerFoundException.class)
	public Object handleNoHandlerFoundException(NoHandlerFoundException ex) {
		return invoke("找不到请求地址~", ex, false);
	}
	
	/**
	 * 	全局异常
	 * @param ex
	 * @return
	 */
	@ExceptionHandler(Exception.class)
	public Object handleException(Exception ex) {
		return invoke("系统想罢工,稍后重试~", ex, true);
	}
	
	/**
	 * 
	 * @param errMsg
	 * @param ex
	 * @return
	 */
	private Object invoke(String errMsg, Exception ex, boolean logStackTrace) {
		if(logStackTrace) {
			LOGGER.error(ex.getMessage(), ex);
		}else {
			LOGGER.error(ex.getMessage());
		}
		return R.fail(errMsg);
	}
	
}
