/**
 * 
 */
package com.platomix.intchannel.manager;

import java.util.concurrent.ConcurrentHashMap;

import org.springframework.stereotype.Component;

/**
 * @author wookvn
 * 	默认缓存实现类
 */
@Component
public class ConcurrentHashMapCacheManager implements ICacheManager {

	private final static ConcurrentHashMap<String, ConcurrentHashMapCacheManager.Entry> cacheResult = 
			new ConcurrentHashMap<String, ConcurrentHashMapCacheManager.Entry>();
	
	@Override
	public void set(String key, Object value, long secords) {
		cacheResult.put(key, new ConcurrentHashMapCacheManager.Entry(secords*1000, value));
	}

	@Override
	public boolean add(String key, Object value, long secords) {
		return cacheResult.containsKey(key) ? false : cacheResult.put(key, new ConcurrentHashMapCacheManager.Entry(secords*1000, value)) != null;
	}

	@Override
	public Object get(String key) {
		Entry entry = cacheResult.get(key);
		if(entry != null && System.currentTimeMillis() - entry.getStartMillis() >= entry.getExpireMillis()) {
			cacheResult.remove(key);
			return null;
		}
		return entry != null ? entry.getValue() : null;
	}

	@Override
	public void delete(String key) {
		cacheResult.remove(key);
	}
	
	@Override
	public void flush() {
		cacheResult.clear();
	}
	
	static class Entry {
		//过期毫秒数
		private long expireMillis;
		//存入数据的毫秒数
		private long startMillis;
		private Object value;
		
		public Entry() {
			super();
		}

		public Entry(long expireMillis, Object value) {
			super();
			this.value = value;
			this.expireMillis = expireMillis;
			this.startMillis = System.currentTimeMillis();
		}

		/**
		 * @return the expireMillis
		 */
		public long getExpireMillis() {
			return expireMillis;
		}

		/**
		 * @param expireMillis the expireMillis to set
		 */
		public void setExpireMillis(long expireMillis) {
			this.expireMillis = expireMillis;
		}

		/**
		 * @return the startMillis
		 */
		public long getStartMillis() {
			return startMillis;
		}

		/**
		 * @param startMillis the startMillis to set
		 */
		public void setStartMillis(long startMillis) {
			this.startMillis = startMillis;
		}

		/**
		 * @return the value
		 */
		public Object getValue() {
			return value;
		}

		/**
		 * @param value the value to set
		 */
		public void setValue(Object value) {
			this.value = value;
		}
	}
}
