/**
 *
 */
package com.platomix.intchannel.service;

import com.itextpdf.text.*;
import com.itextpdf.text.pdf.BaseFont;
import com.itextpdf.text.pdf.PdfPCell;
import com.itextpdf.text.pdf.PdfPTable;
import com.itextpdf.text.pdf.PdfWriter;
import com.platomix.intchannel.model.DateRangeAccount;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Component;

import java.io.ByteArrayOutputStream;
import java.math.BigDecimal;

/**
 * @author wookvn
 *
 *	导出PDF
 */
@Component
public class PdfExportService {



	/**
	 * 导出互联网1第一次结算金额 - PDF文件
	 * @param dateRangeAccount
	 * @return
	 * @throws Exception
	 */
	public void createH1OnePdf(DateRangeAccount dateRangeAccount, ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = dateRangeAccount.getTheMonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(2);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(2);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《联通在线渠道推广%s%s月预结金额确认单》", year, month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(2);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				"1.甲方为推广其产品或服务，同意按照本协议的规定在乙方渠道推广其产品或服务，按合作结算渠道推广费用。\n" +
						"2.本统计表自双方签署盖章之日起生效。\n" +
						"3.本统计表一式贰份，双方各执壹份。\n" +
						"4.请乙方收到此单据后  3  日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方：" + dateRangeAccount.getCompany(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getSpname(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("平台有效用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getOnPlatform() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("T+1 预结用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getOnDateRange() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("T+1 预结金额", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyOneReal() + "  元", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		// 配置行间距
		cell.addElement(new Paragraph(24,
				"乙方： \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}

	/**
	 * 导出互联网1第二次结算金额 - PDF文件
	 * @param dateRangeAccount
	 * @return
	 */
	public void createH1TwoPdf(DateRangeAccount dateRangeAccount, ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = dateRangeAccount.getTheMonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(2);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(2);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《联通在线渠道推广%s%s月清算金额确认单》", year, month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(2);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				"1.甲方为推广其产品或服务，同意按照本协议的规定在乙方渠道推广其产品或服务，按合作结算渠道推广费用。\n" +
						"2.本统计表自双方签署盖章之日起生效。\n" +
						"3.本统计表一式贰份，双方各执壹份。\n" +
						"4.请乙方收到此单据后  3  日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方：" + dateRangeAccount.getCompany(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getSpname(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		if(dateRangeAccount.getChannelName().equals("腾讯收银台")){
			cell = new PdfPCell(new Phrase("平台有效用户数", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
			cell = new PdfPCell(new Phrase(dateRangeAccount.getOnDateRange() + "  户", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);

			cell = new PdfPCell(new Phrase("平台有效用户清算金额", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
			cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyTwoReal() + "  元", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
		}else {
			cell = new PdfPCell(new Phrase("PRM有效用户数", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
			cell = new PdfPCell(new Phrase(dateRangeAccount.getAccountUsers() + "  户", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);

			cell = new PdfPCell(new Phrase("PRM有效用户清算金额", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
			cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyTwoReal() + "  元", titleFont));
			cell.setPadding(10f);
			table.addCell(cell);
		}

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		// 配置行间距
		cell.addElement(new Paragraph(24,
				"乙方： \n" +
						"\n" +
						"盖章：\n" +
						"\n" +
						"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}




	/**
	 * 导出第一次结算金额 - PDF文件
	 * @param dateRangeAccount
	 * @return
	 * @throws Exception
	 */
	public void createOnePdf(DateRangeAccount dateRangeAccount, ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = dateRangeAccount.getTheMonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
//		InputStream stream = cpr.getInputStream();
//		byte[] st1 = new byte[stream.available()];
//		stream.read(st1);
//		BaseFont bf = BaseFont.createFont("simfang.ttf", BaseFont.IDENTITY_H, BaseFont.EMBEDDED, BaseFont.NOT_CACHED, st1, st1);
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(2);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(2);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《联通在线渠道推广%s%s月预结金额确认单》", year, month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(2);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				"1.甲方为推广其产品或服务，同意按照本协议的规定在乙方渠道推广其产品或服务，按合作结算渠道推广费用。\n" +
				"2.本统计表自双方签署盖章之日起生效。\n" +
				"3.本统计表一式贰份，双方各执壹份。\n" +
				"4.请乙方收到此单据后  3  日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方：" + dateRangeAccount.getCompany(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getSpname(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("平台有效用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getOnPlatform() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("T+1 预结用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getOnDateRange() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		/*cell = new PdfPCell(new Phrase("400扣罚", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyOneDiscount() + "  元", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);*/

		cell = new PdfPCell(new Phrase("T+1 预结金额", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyOneReal() + "  元", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		// 配置行间距
		cell.addElement(new Paragraph(24,
				"乙方： \n" +
				"\n" +
				"盖章：\n" +
				"\n" +
				"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}

	/**
	 * 导出第二次结算金额 - PDF文件
	 * @param dateRangeAccount
	 * @return
	 */
	public void createTwoPdf(DateRangeAccount dateRangeAccount, ByteArrayOutputStream baos) throws Exception {
		Document document = new Document();
		PdfWriter.getInstance(document, baos);
		document.open();

		String theMonthStr = dateRangeAccount.getTheMonth().toString();
		String year = theMonthStr.substring(0, 4), month = theMonthStr.substring(4);

		// 使用语言包字体
		BaseFont abf = BaseFont.createFont("STSong-Light", "UniGB-UCS2-H", BaseFont.NOT_EMBEDDED);
		// 外部字体
		ClassPathResource cpr = new ClassPathResource("/fonts/simfang.ttf");
		BaseFont bf = BaseFont.createFont(cpr.getPath(), BaseFont.IDENTITY_H, BaseFont.EMBEDDED);
		Font titleFont = new Font(bf, 12, Font.NORMAL);

		PdfPTable table = new PdfPTable(2);

		PdfPCell cell = new PdfPCell();
		cell.setHorizontalAlignment(Element.ALIGN_CENTER);
		cell.setVerticalAlignment(Element.ALIGN_CENTER);
		cell.setColspan(2);
		cell.setPaddingBottom(10f);
		Paragraph paragraph = new Paragraph(String.format("《联通在线渠道推广%s%s月清算金额确认单》", year, month), new Font(abf, 13, Font.BOLD));
		paragraph.setAlignment(Paragraph.ALIGN_CENTER);
		cell.addElement(paragraph);
		table.addCell(cell);

		cell = new PdfPCell();
		cell.setColspan(2);
		cell.setPadding(10f);
		Paragraph para = new Paragraph(
				"1.甲方为推广其产品或服务，同意按照本协议的规定在乙方渠道推广其产品或服务，按合作结算渠道推广费用。\n" +
				"2.本统计表自双方签署盖章之日起生效。\n" +
				"3.本统计表一式贰份，双方各执壹份。\n" +
				"4.请乙方收到此单据后  3  日予以确认。", titleFont);
		para.setSpacingBefore(10f);
		cell.addElement(para);
		table.addCell(cell);


		cell = new PdfPCell(new Phrase("甲方：联通在线信息科技有限公司", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("乙方：" + dateRangeAccount.getCompany(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("统计周期", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(String.format("%s 年 %s 月", year, month), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("产品名称", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getSpname(), titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("PRM有效用户数", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getAccountUsers() + "  户", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		BigDecimal totalPrice = dateRangeAccount.getMoneyTwoDiscount1()
				.add(dateRangeAccount.getMoneyTwoDiscount2()).subtract(dateRangeAccount.getMoneyTwoDiscount3())
				.add(dateRangeAccount.getMoneyTwoDiscount4());
		cell = new PdfPCell(new Phrase("扣款合计", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(totalPrice + "  元", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("PRM有效用户清算金额", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase(dateRangeAccount.getMoneyTwoReal() + "  元", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);

		cell = new PdfPCell(new Phrase("乙方确认意见", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);
		cell = new PdfPCell(new Phrase("  ", titleFont));
		cell.setPadding(10f);
		table.addCell(cell);


		// 配置行间距
		cell.addElement(new Paragraph(24,
				"乙方： \n" +
				"\n" +
				"盖章：\n" +
				"\n" +
				"日期：",
				titleFont));
		cell.setColspan(2);
		cell.setPadding(10f);
		table.addCell(cell);
		document.add(table);
		document.close();
	}

}
